import React from 'react';
import { Inventory as InventoryHelpers } from '../inventory-helpers/inventory';
import { InventoryJSONData } from '../inventory-helpers/types';
import { Checkout } from '../checkout-sdk/checkout';
import { Cart, Item, LineItem, StoreConfig, ItemId, SupportedPlatform, ProductType, CartUpdates } from '../types';
import { BigCommerceSDKAddShippingAddressProps } from '../checkout-sdk/platforms/big-commerce/management-api/types';
import { ProductInventory } from '../inventory-helpers/platforms/types';
export declare type CartState = Cart & {
    isCartShown: boolean;
    inventory: InventoryJSONData;
};
interface ItemIdAndProductType {
    id: ItemId;
    type?: ProductType;
}
declare type ProductSearchParams = ItemId | ItemIdAndProductType;
declare type Action = {
    type: 'initial load';
    payload: Cart;
} | {
    type: 'initial load with inventory';
    payload: Cart & {
        inventory: InventoryJSONData;
    };
} | {
    type: 'update cart';
    payload: Cart;
} | {
    type: 'show cart';
} | {
    type: 'hide cart';
} | {
    type: 'update inventory';
    payload: InventoryJSONData;
} | {
    type: 'add currencies';
    payload: string[];
};
declare type Dispatch = (action: Action) => void;
declare type ActionDispatchers = ReturnType<typeof getActionsAvailableToUsers>;
export declare function cartReducer(state: CartState, action: Action): CartState;
declare function CartProvider({ children, platform, storeConfig, }: {
    children: React.ReactNode;
    platform: SupportedPlatform;
    storeConfig: StoreConfig;
}): JSX.Element | null;
declare function getActionsAvailableToUsers(dispatch: Dispatch, checkout: Checkout, stateRef: React.MutableRefObject<CartState>, inventoryHelpers: InventoryHelpers, defaultProductType: ProductType): {
    fetchProduct: (searchParams: ProductSearchParams) => Promise<import("../types").Product | (import("../checkout-sdk/platforms/shopify/storefront-api/types").ShopifyStorefrontProductVariantWithProduct | import("../checkout-sdk/platforms/shopify/ajax-api/types").ShopifyAjaxProductVariant)>;
    addItems: (items: Item | Item[]) => Promise<Cart>;
    updateItems: (items: Item | Item[]) => Promise<Cart>;
    removeItems: (items: ItemId | ItemId[]) => Promise<Cart>;
    updateCart: (cartUpdates: CartUpdates) => Promise<Cart>;
    showCart: () => void;
    hideCart: () => void;
    getProductTrackingData: (item: LineItem) => import("../checkout-sdk/platforms/shopify/storefront-api/types").ShopifyStorefrontProductTrackingData | import("../checkout-sdk/platforms/shopify/ajax-api/types").ShopifyAjaxProductTrackingData;
    isProductInInventory: () => void;
    isProductAvailableForSale: (searchParams: ProductSearchParams) => Promise<ProductInventory['availableForSale']>;
    getProductQuantity: (searchParams: ProductSearchParams) => Promise<ProductInventory['quantity']>;
    getProductMinOrder: (searchParams: ProductSearchParams) => Promise<ProductInventory['minOrder']>;
    getProductMaxOrder: (searchParams: ProductSearchParams) => Promise<ProductInventory['maxOrder']>;
    getProductPrice: (searchParams: ProductSearchParams) => Promise<ProductInventory['price']>;
    getCurrencies: () => Promise<string[]>;
    selectCurrency: (currency: string) => Promise<Cart>;
    getShippingQuotes: (shippingAddress: BigCommerceSDKAddShippingAddressProps['shippingAddress']) => Promise<import("../types").BigCommerceShippingOption[] | undefined>;
};
declare function useInventoryActions(): InventoryHelpers;
declare function useCartState(): CartState;
declare function useCartActions(): ActionDispatchers;
declare function useCart(): Array<CartState | ActionDispatchers>;
export { CartProvider, useInventoryActions, useCartState, useCartActions, useCart };
