"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useCart = exports.useCartActions = exports.useCartState = exports.useInventoryActions = exports.CartProvider = exports.cartReducer = void 0;
const tslib_1 = require("tslib");
/* eslint-disable @typescript-eslint/strict-boolean-expressions */
/* eslint-disable no-restricted-syntax */
/* eslint-disable react-hooks/exhaustive-deps */
/* eslint-disable eqeqeq */
/* eslint-disable @typescript-eslint/camelcase */
/* eslint-disable react-hooks/rules-of-hooks */
const react_1 = tslib_1.__importStar(require("react"));
const checkout_sdk_1 = require("../checkout-sdk");
const inventory_helpers_1 = require("../inventory-helpers");
const validations_1 = require("./validations");
function isItemIdAndProductType(x) {
    return typeof x === 'object';
}
function parseProductSearchParams(searchParams, defaultProductType) {
    if (isItemIdAndProductType(searchParams)) {
        return Object.assign(Object.assign({}, searchParams), { type: searchParams.type != null ? searchParams.type : defaultProductType });
    }
    return {
        id: searchParams,
        type: defaultProductType,
    };
}
const initialState = {
    id: '',
    items: [],
    inventory: {
        products: undefined,
        productVariants: undefined,
        status: 'loading',
    },
    currencyCode: '',
    subtotalPrice: '',
    totalPrice: '',
    discountAmount: null,
    isCartShown: false,
    checkoutUrl: '',
    currencies: [],
    consignment: null,
};
const CartStateContext = react_1.default.createContext(initialState);
const CartDispatchContext = react_1.default.createContext({});
const InventoryHelpersContext = react_1.default.createContext({});
function cartReducer(state, action) {
    switch (action.type) {
        case 'initial load':
        case 'initial load with inventory': {
            return Object.assign(Object.assign({}, state), action.payload);
        }
        case 'update cart': {
            return Object.assign(Object.assign({}, state), action.payload);
        }
        case 'show cart': {
            return Object.assign(Object.assign({}, state), { isCartShown: true });
        }
        case 'hide cart': {
            return Object.assign(Object.assign({}, state), { isCartShown: false });
        }
        case 'update inventory': {
            return Object.assign(Object.assign({}, state), { inventory: Object.assign({}, action.payload) });
        }
        case 'add currencies': {
            return Object.assign(Object.assign({}, state), { currencies: action.payload });
        }
        default: {
            throw new Error('Wrong action type sent to cartReducer.');
        }
    }
}
exports.cartReducer = cartReducer;
function CartProvider({ children, platform, storeConfig, }) {
    const { platformApiType = 'graphql', isInventoryJSONDisabled } = storeConfig;
    /**
     * This is necessary to guard against 'graphql' not beign supported by the BigCommerce
     * integration. validateProviderConfigInputs should throw an error before we reach this point.
     *
     * This can be safely removed once graphql support is added.
     */
    validations_1.validateProviderConfigInputs({ platform, platformApiType });
    const defaultProductType = {
        shopify: 'ProductVariant',
        big_commerce: 'Product',
    }[platform];
    const createCheckout = checkout_sdk_1.checkouts[platform][platformApiType];
    if (!createCheckout)
        return null;
    const inventoryHelpers = inventory_helpers_1.helpers[platform](Object.assign(Object.assign({}, storeConfig), { defaultProductType }));
    if (!inventoryHelpers)
        return null;
    const [checkout] = react_1.default.useState(() => createCheckout(storeConfig));
    const [state, dispatch] = react_1.default.useReducer(cartReducer, initialState);
    const stateRef = react_1.useRef(initialState);
    react_1.default.useEffect(() => {
        stateRef.current = state;
    }, [state]);
    react_1.default.useEffect(() => {
        let refreshInventoryIntervalId = undefined;
        const storeCartRequest = checkout.getCart();
        if (isInventoryJSONDisabled) {
            storeCartRequest
                .then((cart) => {
                dispatch({
                    type: 'initial load',
                    payload: cart,
                });
            })
                .catch((cart) => {
                dispatch({
                    type: 'initial load',
                    payload: cart,
                });
            });
        }
        else {
            const productInventoryRequest = inventoryHelpers.fetchInventory();
            Promise.all([storeCartRequest, productInventoryRequest])
                .then(([cart, productInventoryJSON]) => {
                dispatch({
                    type: 'initial load with inventory',
                    payload: Object.assign(Object.assign({}, cart), { inventory: {
                            products: productInventoryJSON === null || productInventoryJSON === void 0 ? void 0 : productInventoryJSON.products,
                            productVariants: productInventoryJSON === null || productInventoryJSON === void 0 ? void 0 : productInventoryJSON.productVariants,
                            status: 'loaded',
                        } }),
                });
                refreshInventoryIntervalId = inventoryHelpers.refreshInventoryOnInterval((inventory) => {
                    dispatch({
                        type: 'update inventory',
                        payload: {
                            products: inventory.products,
                            productVariants: inventory.productVariants,
                            status: 'loaded',
                        },
                    });
                });
            })
                .catch((cart) => {
                dispatch({
                    type: 'initial load with inventory',
                    payload: Object.assign(Object.assign({}, cart), { inventory: {
                            products: null,
                            productVariants: null,
                            status: 'error',
                        } }),
                });
            });
        }
        return () => {
            if (typeof refreshInventoryIntervalId === 'number') {
                clearInterval(refreshInventoryIntervalId);
            }
        };
    }, []);
    return (react_1.default.createElement(CartStateContext.Provider, { value: state },
        react_1.default.createElement(CartDispatchContext.Provider, { value: getActionsAvailableToUsers(dispatch, checkout, stateRef, inventoryHelpers, defaultProductType) },
            react_1.default.createElement(InventoryHelpersContext.Provider, { value: inventoryHelpers }, children))));
}
exports.CartProvider = CartProvider;
function getActionsAvailableToUsers(dispatch, checkout, stateRef, inventoryHelpers, defaultProductType) {
    return {
        fetchProduct: (searchParams) => tslib_1.__awaiter(this, void 0, void 0, function* () {
            // This method originally fetched only Product type so we need to keep it
            // as the default type here
            const { id, type } = parseProductSearchParams(searchParams, 'Product');
            if (type === 'Product') {
                return checkout.fetchProduct(id);
            }
            return checkout.fetchProductVariant(id);
        }),
        addItems: (items) => tslib_1.__awaiter(this, void 0, void 0, function* () {
            const cart = yield checkout.addItemsToCart(items);
            updateCart(dispatch, cart);
            return cart;
        }),
        updateItems: (items) => tslib_1.__awaiter(this, void 0, void 0, function* () {
            const cart = yield checkout.updateItemsInCart(items);
            updateCart(dispatch, cart);
            return cart;
        }),
        removeItems: (items) => tslib_1.__awaiter(this, void 0, void 0, function* () {
            const cart = yield checkout.removeItemsFromCart(items);
            updateCart(dispatch, cart);
            return cart;
        }),
        updateCart: (cartUpdates) => tslib_1.__awaiter(this, void 0, void 0, function* () {
            const cart = yield checkout.updateCart(cartUpdates);
            updateCart(dispatch, cart);
            return cart;
        }),
        showCart: () => {
            dispatch({ type: 'show cart' });
        },
        hideCart: () => {
            dispatch({ type: 'hide cart' });
        },
        getProductTrackingData: (item) => {
            return checkout.getProductTrackingData(item);
        },
        isProductInInventory: () => {
            console.warn(`
      Deprecation Warning:
      'isProductInInventory is deprecated.
      Please use 'isProductAvailableForSale()' instead.
              `);
        },
        isProductAvailableForSale: (searchParams) => {
            const { id, type } = parseProductSearchParams(searchParams, defaultProductType);
            return inventoryHelpers.isProductAvailableForSale(id, type);
        },
        getProductQuantity: (searchParams) => {
            const { id, type } = parseProductSearchParams(searchParams, defaultProductType);
            return inventoryHelpers.getProductQuantity(id, type);
        },
        getProductMinOrder: (searchParams) => {
            const { id, type } = parseProductSearchParams(searchParams, defaultProductType);
            return inventoryHelpers.getProductMinOrder(id, type);
        },
        getProductMaxOrder: (searchParams) => {
            const { id, type } = parseProductSearchParams(searchParams, defaultProductType);
            return inventoryHelpers.getProductMaxOrder(id, type);
        },
        getProductPrice: (searchParams) => {
            const { id, type } = parseProductSearchParams(searchParams, defaultProductType);
            return inventoryHelpers.getProductPrice(id, type);
        },
        getCurrencies: () => tslib_1.__awaiter(this, void 0, void 0, function* () {
            const data = yield checkout.fetchCurrencies();
            dispatch({ type: 'add currencies', payload: data });
            return data;
        }),
        selectCurrency: (currency) => tslib_1.__awaiter(this, void 0, void 0, function* () {
            const items = stateRef.current.items;
            const lineItems = items.map(({ quantity, variant, attributes }) => ({
                quantity,
                variantId: variant.id,
                attributes,
            }));
            const cart = yield checkout.selectCurrency({ currency, lineItems });
            updateCart(dispatch, cart);
            return cart;
        }),
        getShippingQuotes: (shippingAddress) => tslib_1.__awaiter(this, void 0, void 0, function* () {
            var _a, _b;
            const { consignment, items } = stateRef.current;
            const lineItems = items.map(({ id, quantity }) => ({ id, quantity }));
            const cart = yield ((consignment === null || consignment === void 0 ? void 0 : consignment.id)
                ? checkout.updateShippingAddress({
                    consignmentId: consignment.id,
                    lineItems,
                    shippingAddress,
                })
                : checkout.addShippingAddress({
                    lineItems,
                    shippingAddress,
                }));
            updateCart(dispatch, cart);
            return (_b = (_a = cart) === null || _a === void 0 ? void 0 : _a.consignment) === null || _b === void 0 ? void 0 : _b.availableShippingOptions;
        }),
    };
}
function updateCart(dispatch, payload) {
    dispatch({ type: 'update cart', payload });
}
function useInventoryActions() {
    return react_1.default.useContext(InventoryHelpersContext);
}
exports.useInventoryActions = useInventoryActions;
function useCartState() {
    return react_1.default.useContext(CartStateContext);
}
exports.useCartState = useCartState;
function useCartActions() {
    return react_1.default.useContext(CartDispatchContext);
}
exports.useCartActions = useCartActions;
function useCart() {
    return [useCartState(), useCartActions()];
}
exports.useCart = useCart;
