"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Checkout = void 0;
const tslib_1 = require("tslib");
const ensure_array_1 = require("../utils/ensure-array");
class Checkout {
    constructor({ platform }) {
        this.platform = platform;
    }
    fetchProduct(id) {
        if (!this.platform.fetchProduct) {
            throw new Error('Operation not supported by the selected platform.');
        }
        return this.platform.fetchProduct(id);
    }
    fetchProductVariant(id) {
        if (!this.platform.fetchProductVariant) {
            throw new Error('Operation not supported by the selected platform.');
        }
        return this.platform.fetchProductVariant(id);
    }
    fetchCurrencies() {
        if (!this.platform.fetchCurrencies) {
            throw new Error('Operation not supported by the selected platform.');
        }
        return this.platform.fetchCurrencies();
    }
    selectCurrency(props) {
        if (!this.platform.selectCurrency) {
            throw new Error('Operation not supported by the selected platform.');
        }
        return this.platform.selectCurrency(props);
    }
    addItemsToCart(itemsToAdd) {
        const items = ensure_array_1.ensureArray(itemsToAdd);
        return this.platform.addItemsToCart(items);
    }
    updateItemsInCart(itemsToUpdate) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const items = ensure_array_1.ensureArray(itemsToUpdate);
            return this.platform.updateItemsInCart(items);
        });
    }
    removeItemsFromCart(itemIdsToRemove) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const itemIds = ensure_array_1.ensureArray(itemIdsToRemove);
            return this.platform.removeItemsFromCart(itemIds);
        });
    }
    updateCart(cartUpdates) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            if (!this.platform.updateCart) {
                throw new Error('Operation not supported by the selected platform.');
            }
            return this.platform.updateCart(cartUpdates);
        });
    }
    getCart() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return this.platform.getCart();
        });
    }
    addShippingAddress(props) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            if (!this.platform.addShippingAddress) {
                throw new Error('Operation not supported by the selected platform.');
            }
            return this.platform.addShippingAddress(props);
        });
    }
    updateShippingAddress(props) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            if (!this.platform.updateShippingAddress) {
                throw new Error('Operation not supported by the selected platform.');
            }
            return this.platform.updateShippingAddress(props);
        });
    }
    getProductTrackingData(item) {
        return this.platform.getProductTrackingData(item);
    }
    getItemIdInPlatformSpecificFormat(itemId, productType) {
        return this.platform.getItemIdInPlatformSpecificFormat(itemId, productType);
    }
}
exports.Checkout = Checkout;
