/**
 * this type should match:
 * https://developer.bigcommerce.com/api-reference/cart-checkout/server-server-cart-api/cart/getacart#responses
 */
declare type BigCommerceAPICart = {
    id: string;
    parent_id?: string;
    customer_id: number;
    email: string;
    currency: {
        code: string;
    };
    tax_included: boolean;
    base_amount: number;
    discount_amount: number;
    cart_amount: number;
    line_items: BigCommerceAPILineItems;
    redirect_urls: {
        checkout_url: string;
    };
};
interface BigCommerceAPILineItemOption {
    name_id: number;
    value_id: number;
}
interface BigCommerceAPILineItem {
    id: string;
    product_id: number;
    variant_id: number;
    quantity: number;
    name: string;
    sku: string;
    list_price: number;
    image_url: string;
    url: string;
    coupon_amount: number;
    discount_amount: number;
    discounts: {
        id: string;
        discounted_amount: number;
    }[];
    extended_list_price: number;
    extended_sale_price: number;
    is_mutable: boolean;
    is_require_shipping: boolean;
    parent_id: number | null;
    sale_price: number;
    taxable: boolean;
    options: BigCommerceAPILineItemOption[];
}
declare type BigCommerceAPILineItemPayload = {
    id: string;
    product_id: number;
    variant_id: number;
    quantity: number;
    option_selections?: BigCommerceAPILineItemOption[];
};
interface BigCommerceAPILineItems {
    custom_items: BigCommerceAPILineItem[];
    digital_items: BigCommerceAPILineItem[];
    gift_certificates: BigCommerceAPILineItem[];
    physical_items: BigCommerceAPILineItem[];
}
interface BigCommerceAPIAddress {
    id: string;
    first_name: string;
    last_name: string;
    email: string;
    company: string;
    address1: string;
    address2: string;
    city: string;
    state_or_province: string;
    state_or_province_code: string;
    country_code: string;
    postal_code: string;
    phone: string;
    custom_fields: {
        field_id: string;
        field_value: string;
    }[];
}
interface BigCommerceAPIShippingOption {
    id: string;
    type: string;
    description: string;
    image_url: string;
    cost: number;
    transit_time: string;
    additional_description: string;
}
interface BigCommerceAPIConsignment {
    id: string;
    shipping_address: BigCommerceAPIAddress;
    available_shipping_options: BigCommerceAPIShippingOption[];
    selected_shipping_option: BigCommerceAPIShippingOption;
    coupon_discounts: {
        code: string;
        amount: number;
    }[];
    discounts: {
        id: number;
    }[];
    shipping_cost_inc_tax: number;
    shipping_cost_ex_tax: number;
    handling_cost_inc_tax: number;
    handling_cost_ex_tax: number;
    line_item_ids: string[];
}
interface BigCommerceAPICheckout {
    id: string;
    cart: BigCommerceAPICart;
    billing_address: BigCommerceAPIAddress;
    consignments: BigCommerceAPIConsignment[];
    taxes: {
        name: string;
        amount: number;
    }[];
    coupons: {
        id: number;
        code: string;
        discounted_amount: number;
        coupon_type: number;
    }[];
    order_id: string;
    shipping_cost_total_inc_tax: number;
    shipping_cost_total_ex_tax: number;
    handling_cost_total_inc_tax: number;
    handling_cost_total_ex_tax: number;
    tax_total: number;
    subtotal_inc_tax: number;
    subtotal_ex_tax: number;
    grand_total: number;
    created_time: string;
    updated_time: string;
    customer_message: string;
}
interface BigCommerceSDKShippingAddress {
    countryCode?: string;
    city?: string;
    state?: string;
    stateCode?: string;
    postalCode: string;
    email?: string;
    firstName?: string;
    lastName?: string;
    address1?: string;
    phone?: string;
}
interface BigCommerceSDKAddShippingAddressProps {
    lineItems: {
        id: string;
        quantity: number;
    }[];
    shippingAddress: BigCommerceSDKShippingAddress;
}
interface BigCommerceSDKUpdateShippingAddressProps extends BigCommerceSDKAddShippingAddressProps {
    consignmentId: string;
}
export { BigCommerceAPICart, BigCommerceAPILineItems, BigCommerceAPILineItem, BigCommerceAPIAddress, BigCommerceAPICheckout, BigCommerceAPIConsignment, BigCommerceAPIShippingOption, BigCommerceAPILineItemPayload, BigCommerceSDKShippingAddress, BigCommerceSDKAddShippingAddressProps, BigCommerceSDKUpdateShippingAddressProps, };
