"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.mapCheckoutToCart = void 0;
const map_item_1 = require("./map-item");
const map_consignment_1 = require("./map-consignment");
/**
 * Maps a BigCommerce Checkout returned from the Storefront API
 * into a frontend-checkout Cart
 *
 * @param {BigCommerceAPICheckout} checkout
 * @returns {Cart} a checkout cart instance
 */
const mapCheckoutToCart = (checkout) => {
    var _a;
    return ({
        id: checkout.id,
        currencyCode: checkout.cart.currency.code,
        subtotalPrice: checkout.cart.base_amount,
        totalPrice: checkout.grand_total,
        discountAmount: checkout.cart.discount_amount,
        consignment: ((_a = checkout.consignments) === null || _a === void 0 ? void 0 : _a.length) ? map_consignment_1.mapConsignment(checkout.consignments[0]) : null,
        items: [
            ...checkout.cart.line_items.physical_items.map(map_item_1.mapItem),
            ...checkout.cart.line_items.custom_items.map(map_item_1.mapItem),
            ...checkout.cart.line_items.digital_items.map(map_item_1.mapItem),
            ...checkout.cart.line_items.gift_certificates.map(map_item_1.mapItem),
        ],
        checkoutUrl: checkout.cart.redirect_urls.checkout_url,
        taxTotal: checkout.tax_total,
        coupons: checkout.coupons.map(({ id, code, coupon_type, discounted_amount }) => ({
            id,
            code,
            couponType: coupon_type,
            discountedAmount: discounted_amount,
        })),
    });
};
exports.mapCheckoutToCart = mapCheckoutToCart;
