"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.mapConsignment = void 0;
const mapShippingOption = (availableShippingOption) => ({
    id: availableShippingOption.id,
    type: availableShippingOption.type,
    description: availableShippingOption.description,
    imageUrl: availableShippingOption.image_url,
    cost: availableShippingOption.cost,
    transitTime: availableShippingOption.transit_time,
    additionalDescription: availableShippingOption.additional_description,
});
const mapConsignment = (consignment) => ({
    id: consignment.id,
    shippingAddress: {
        id: consignment.shipping_address.id,
        firstName: consignment.shipping_address.first_name,
        lastName: consignment.shipping_address.last_name,
        email: consignment.shipping_address.email,
        company: consignment.shipping_address.company,
        address1: consignment.shipping_address.address1,
        address2: consignment.shipping_address.address2,
        city: consignment.shipping_address.city,
        state: consignment.shipping_address.state_or_province,
        stateCode: consignment.shipping_address.state_or_province_code,
        countryCode: consignment.shipping_address.country_code,
        postalCode: consignment.shipping_address.postal_code,
        phone: consignment.shipping_address.phone,
        customFields: consignment.shipping_address.custom_fields.map(({ field_id, field_value }) => ({
            id: field_id,
            value: field_value,
        })),
    },
    availableShippingOptions: consignment.available_shipping_options.map(mapShippingOption),
    selectedShippingOption: consignment.selected_shipping_option
        ? mapShippingOption(consignment.selected_shipping_option)
        : null,
    couponDiscounts: consignment.coupon_discounts,
    discounts: consignment.discounts,
    shippingCostIncTax: consignment.shipping_cost_inc_tax,
    shippingCostExTax: consignment.shipping_cost_ex_tax,
    handlingCostIncTax: consignment.handling_cost_inc_tax,
    handlingCostExTax: consignment.handling_cost_ex_tax,
    lineItemIds: consignment.line_item_ids,
});
exports.mapConsignment = mapConsignment;
