"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.mapItem = void 0;
const tslib_1 = require("tslib");
/**
 * Maps a BigCommerce Line Item returned from the REST API
 * into a frontend-checkout Item to be added to the Cart instance
 *
 * @param {BigCommerceAPILineItem} item
 * @returns {Item} Item instance with BigCommerce specific properties
 */
const mapItem = (item) => {
    const { id, sku, product_id, list_price, sale_price, variant_id, image_url, coupon_amount, discount_amount, discounts, options, extended_list_price, extended_sale_price, is_mutable, is_require_shipping, parent_id, taxable } = item, rest = tslib_1.__rest(item, ["id", "sku", "product_id", "list_price", "sale_price", "variant_id", "image_url", "coupon_amount", "discount_amount", "discounts", "options", "extended_list_price", "extended_sale_price", "is_mutable", "is_require_shipping", "parent_id", "taxable"]);
    return Object.assign({ id: product_id, SKU: sku, lineItemId: id, listPrice: list_price, salePrice: sale_price, variantId: variant_id, imageUrl: image_url, couponAmount: coupon_amount, discountAmount: discount_amount, discounts: discounts === null || discounts === void 0 ? void 0 : discounts.map(({ id, discounted_amount }) => ({
            id,
            discountedAmount: discounted_amount,
        })), extendedListPrice: extended_list_price, extendedSalePrice: extended_sale_price, isMutable: is_mutable, isShippingRequired: is_require_shipping, isTaxable: taxable, parentId: parent_id, optionSelections: options
            ? options.map(({ name_id, value_id }) => ({
                optionId: name_id,
                optionValue: value_id,
            }))
            : options }, rest);
};
exports.mapItem = mapItem;
