import { Item, LineItem } from '../../../../types';
interface ShopifyAjaxProductVariant {
    id: number;
    title: string;
    options: string[];
    option1: string | null;
    option2: string | null;
    option3: string | null;
    price: number;
    weight: number;
    compare_at_price: number | null;
    inventory_management: string;
    available: boolean;
    sku: string | null;
    requires_shipping: boolean;
    taxable: boolean;
    barcode: string;
}
interface ProductOption {
    name: string;
    position: number;
}
interface ShopifyAjaxProduct {
    id: number;
    available: boolean;
    compare_at_price_max: number;
    compare_at_price_min: number;
    compare_at_price_varies: boolean;
    compare_at_price: number | null;
    created_at: string;
    description: string;
    featured_image: string;
    handle: string;
    images: string[];
    options: ProductOption[];
    price_max: number;
    price_min: number;
    price_varies: boolean;
    price: number;
    published_at: string;
    tags: string[];
    title: string;
    type: string;
    url: string;
    variants: ShopifyAjaxProductVariant[];
    vendor: string;
}
interface ShopifyAjaxLineItem {
    id: number;
    discounted_price: number;
    discounts: unknown[];
    featured_image: {
        aspect_ratio: number;
        alt: string;
        height: number;
        url: string;
        width: number;
    };
    final_line_price: number;
    final_price: number;
    gift_card: boolean;
    grams: number;
    handle: string;
    image: string;
    key: string;
    line_level_discount_allocations: unknown[];
    line_level_total_discount: number;
    line_price: number;
    options_with_values: {
        name: string;
        value: string;
    }[];
    original_line_price: number;
    original_price: number;
    price: number;
    product_description: string;
    product_has_only_default_variant: boolean;
    product_id: number;
    product_title: string;
    product_type: string;
    properties: Record<string, string> | null;
    quantity: number;
    requires_shipping: boolean;
    sku: string | null;
    taxable: boolean;
    title: string;
    total_discount: number;
    url: string;
    variant_id: number;
    variant_options: string[];
    variant_title: string;
    vendor: string;
}
interface CartLevelDiscountApplications {
    allocation_method: string;
    created_at: string;
    description: string | null;
    key: string;
    target_selection: string;
    target_type: string;
    title: string;
    total_allocated_amount: number;
    type: string;
    value_type: string;
    value: string;
}
interface ShopifyAjaxCart {
    attributes: Record<string, string>;
    cart_level_discount_applications: CartLevelDiscountApplications[];
    currency: string;
    item_count: number;
    items: ShopifyAjaxLineItem[];
    items_subtotal_price: number;
    note: string | null;
    original_total_price: number;
    requires_shipping: boolean;
    token: string;
    total_discount: number;
    total_price: number;
    total_weight: number;
}
interface ShopifyAjaxCartUpdates {
    items?: Item[];
    note?: string;
    attributes?: Record<string, string>;
}
interface ShopifyAjaxProductTrackingData {
    id: number;
    variantId: number;
    quantity: number;
    price: number;
    name: string;
    brand: string;
}
interface Meta {
    storeName: string;
}
interface Config {
    /**
     * The domain for the store
     * Typically set to `site.platformPublicDomain`
     */
    storeDomain?: string;
}
declare function isAjaxItem(item: LineItem): item is ShopifyAjaxLineItem;
export { ShopifyAjaxProduct, ShopifyAjaxProductVariant, ShopifyAjaxLineItem, ShopifyAjaxCart, ShopifyAjaxProductTrackingData, ShopifyAjaxCartUpdates, Meta, Config, isAjaxItem, };
