import { LineItem, CreateCartInput } from '../../../../../types';
import { ShopifyStorefrontProduct, Image, ShopifyStorefrontProductVariantWithProduct, ShopifyStorefrontCartType } from '../types';
import { PagedConnection, CartLineGraphQlType, ProductVariantGraphQlType, PresentmentPriceGraphQlType } from './types';
export interface Config {
    /**
     * The domain for the store
     * Typically set to `site.platformPublicDomain`
     */
    storeDomain?: string;
    /**
     * The domain to make requests to shopify to.
     * Typically set to `site.platformDomain`
     */
    platformDomain?: string;
    /**
     * The shopify store access token
     */
    storefrontAccessToken: string;
}
export declare class Client {
    apiUrl: string;
    platformDomain?: string;
    storeDomain?: string;
    defaultHeaders: Record<string, string>;
    constructor(config: Config);
    fetchProductByHandle(handle: string): Promise<ShopifyStorefrontProduct>;
    fetchProduct(id: string): Promise<ShopifyStorefrontProduct>;
    createCart(input?: CreateCartInput): Promise<ShopifyStorefrontCartType>;
    fetchCart(id: string): Promise<ShopifyStorefrontCartType>;
    addCartLines(cartId: string | number, lines: LineItem[]): Promise<ShopifyStorefrontCartType>;
    removeCartLines(cartId: string | number, lineIds: (string | number)[]): Promise<ShopifyStorefrontCartType>;
    updateCartLines(cartId: string | number, lines: Partial<LineItem>[]): Promise<ShopifyStorefrontCartType>;
    fetchProductVariant(id: string): Promise<ShopifyStorefrontProductVariantWithProduct>;
    fetchCartLinesPage(cartId: string | number, cursor?: string, pageSize?: number): Promise<PagedConnection<CartLineGraphQlType>>;
    fetchProductImagesPage(productId: string, cursor?: string, pageSize?: number): Promise<PagedConnection<Image>>;
    fetchProductVariantsPage(productId: string, cursor?: string, pageSize?: number): Promise<PagedConnection<ProductVariantGraphQlType>>;
    fetchPresentmentPricesPage(productVariantId: string, cursor?: string, pageSize?: number): Promise<PagedConnection<PresentmentPriceGraphQlType>>;
    fetchCurrencies(): Promise<string[]>;
    post<TResult>(queryOrMutation: string, headers?: Record<string, string>): Promise<TResult>;
}
