"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseCheckoutUrl = exports.mapProductVariantWithProductGraphQlTypeToShopifyStorefrontProductVariantWithProduct = exports.mapProductVariantGraphQlTypeToShopifyStorefrontProductVariant = exports.mapCheckoutLineItemGraphQlTypeToShopifyStorefrontLineItem = exports.mapCartGraphQlTypeToShopifyStorefrontCart = exports.mapProductGraphQlTypeToProduct = void 0;
const tslib_1 = require("tslib");
const paged_connection_helpers_1 = require("./utils/paged-connection-helpers");
function mapProductGraphQlTypeToProduct(product, client) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const getAllImages = paged_connection_helpers_1.fetchAllNodesForConnection(product.images, (afterCursor) => client.fetchProductImagesPage(product.id, afterCursor));
        const getAllVariants = paged_connection_helpers_1.fetchAllNodesForConnection(product.variants, (afterCursor) => client.fetchProductVariantsPage(product.id, afterCursor))
            .then((variants) => variants.map((x) => mapProductVariantGraphQlTypeToShopifyStorefrontProductVariant(x, client)))
            .then((mapVariants) => Promise.all(mapVariants));
        const [images, variants] = yield Promise.all([getAllImages, getAllVariants]);
        const mapped = Object.assign(Object.assign({}, product), { images,
            variants });
        return mapped;
    });
}
exports.mapProductGraphQlTypeToProduct = mapProductGraphQlTypeToProduct;
function mapCartGraphQlTypeToShopifyStorefrontCart(cart, client) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        if (!cart)
            return null;
        const lineItems = yield paged_connection_helpers_1.fetchAllNodesForConnection(cart.lines, (afterCursor) => client.fetchCartLinesPage(cart.id, afterCursor))
            .then((items) => items.map((item) => mapCheckoutLineItemGraphQlTypeToShopifyStorefrontLineItem(item, client)))
            .then((mapItems) => Promise.all(mapItems));
        const storefrontCart = {
            id: cart.id,
            webUrl: cart.checkoutUrl,
            totalPriceV2: cart.estimatedCost.totalAmount,
            subtotalPriceV2: cart.estimatedCost.subtotalAmount,
            subtotalPrice: cart.estimatedCost.subtotalAmount.amount,
            checkoutUrl: parseCheckoutUrl(cart.checkoutUrl, client),
            lineItemCount: lineItems.length,
            lineItems,
        };
        return storefrontCart;
    });
}
exports.mapCartGraphQlTypeToShopifyStorefrontCart = mapCartGraphQlTypeToShopifyStorefrontCart;
function mapCheckoutLineItemGraphQlTypeToShopifyStorefrontLineItem(line, client) {
    var _a;
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const variant = line.merchandise != null
            ? yield mapProductVariantWithProductGraphQlTypeToShopifyStorefrontProductVariantWithProduct(line.merchandise, client)
            : null;
        const cartLine = {
            id: line.id,
            quantity: line.quantity,
            title: (variant === null || variant === void 0 ? void 0 : variant.product.title) || '',
            discountAllocations: line.discountAllocations.map((discountAllocation) => ({
                allocatedAmount: discountAllocation.discountedAmount,
                discountApplication: {
                    title: discountAllocation.title,
                    code: discountAllocation.code,
                },
            })),
            sellingPlan: ((_a = line.sellingPlanAllocation) === null || _a === void 0 ? void 0 : _a.sellingPlan) || null,
            attributes: line.attributes,
            variant: variant,
        };
        return cartLine;
    });
}
exports.mapCheckoutLineItemGraphQlTypeToShopifyStorefrontLineItem = mapCheckoutLineItemGraphQlTypeToShopifyStorefrontLineItem;
function mapProductVariantGraphQlTypeToShopifyStorefrontProductVariant(productVariant, client) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const presentmentPrices = yield paged_connection_helpers_1.fetchAllNodesForConnection(productVariant.presentmentPrices, (afterCursor) => client.fetchPresentmentPricesPage(productVariant.id, afterCursor));
        const storefrontProductVariant = Object.assign(Object.assign({}, productVariant), { presentmentPrices });
        return storefrontProductVariant;
    });
}
exports.mapProductVariantGraphQlTypeToShopifyStorefrontProductVariant = mapProductVariantGraphQlTypeToShopifyStorefrontProductVariant;
function mapProductVariantWithProductGraphQlTypeToShopifyStorefrontProductVariantWithProduct(productVariant, client) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const storefrontProductVariant = yield mapProductVariantGraphQlTypeToShopifyStorefrontProductVariant(productVariant, client);
        const storefrontProductVariantWithProduct = Object.assign(Object.assign({}, storefrontProductVariant), { product: productVariant.product });
        return storefrontProductVariantWithProduct;
    });
}
exports.mapProductVariantWithProductGraphQlTypeToShopifyStorefrontProductVariantWithProduct = mapProductVariantWithProductGraphQlTypeToShopifyStorefrontProductVariantWithProduct;
function parseCheckoutUrl(checkoutUrl, client) {
    const { storeDomain, platformDomain } = client;
    if (storeDomain != null && platformDomain != null) {
        return checkoutUrl.replace(platformDomain, storeDomain);
    }
    return checkoutUrl;
}
exports.parseCheckoutUrl = parseCheckoutUrl;
