"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getCurrenciesQuery = exports.getAddCartLinesMutation = exports.getUpdateCartLinesMutation = exports.getRemoveCartLinesMutation = exports.getProductVariantsQuery = exports.getProductVariantQuery = exports.getProductImagesPageQuery = exports.getPresentmentPricesPageQuery = exports.getCartQuery = exports.getCartLinesPageQuery = exports.getCreateCartMutation = exports.getProductNodeQuery = exports.getProductByHandleQuery = exports.moneyInfoFragment = void 0;
const constants_1 = require("./constants");
const gql_1 = require("../../../../../utils/gql");
exports.moneyInfoFragment = `
  fragment MoneyInfoFragment on MoneyV2 {
    amount
    currencyCode
  }
`;
const productVariantPricePairConnectionFragment = `
  fragment ProductVariantPricePairConnectionFragment on ProductVariantPricePairConnection {
    pageInfo {
      hasNextPage
      hasPreviousPage
    }
    edges {
      node {
        price {
          ...MoneyInfoFragment
        }
        compareAtPrice {
          ...MoneyInfoFragment
        }
      }
    }
  }
`;
const imageConnectionFragment = `
  fragment ImageConnectionFragment on ImageConnection {
    pageInfo {
      hasNextPage
      hasPreviousPage
    }
    edges {
      cursor
      node {
        id
        src
        altText
      }
    }
  }
`;
const productVariantFragment = `
  fragment ProductVariantFragment on ProductVariant {
    id
    title
    price
    priceV2 {
      ...MoneyInfoFragment
    }
    presentmentPrices(first: 20) {
      ...ProductVariantPricePairConnectionFragment
    }
    weight
    quantityAvailable
    available: availableForSale
    sku
    compareAtPrice
    compareAtPriceV2 {
      ...MoneyInfoFragment
    }
    image {
      id
      src: originalSrc
      altText
    }
    selectedOptions {
      name
      value
    }
    unitPrice {
      ...MoneyInfoFragment
    }
    unitPriceMeasurement {
      measuredType
      quantityUnit
      quantityValue
      referenceUnit
      referenceValue
    }
  }
`;
const productFragment = `
  fragment ProductFragment on Product {
    id
    availableForSale
    createdAt
    updatedAt
    descriptionHtml
    description
    handle
    productType
    title
    vendor
    publishedAt
    onlineStoreUrl
    options {
      name
      values
    }
    images(first: ${constants_1.DEFAULT_PAGE_SIZE}) {
      ...ImageConnectionFragment
    }
    variants(first: ${constants_1.DEFAULT_PAGE_SIZE}) {
      pageInfo {
        hasNextPage
        hasPreviousPage
      }
      edges {
        cursor
        node {
          ...ProductVariantFragment
        }
      }
    }
  }
`;
const userErrorFragment = `
  fragment UserErrorFragment on CartUserError {
    field
    message
  }
`;
const variantWithProductFragment = `
  fragment VariantWithProductFragment on ProductVariant {
    ...ProductVariantFragment
    product {
      id
      handle
      title
    }
  }
`;
const cartLineConnectionFragment = `
  fragment CartLineConnectionFragment on CartLineConnection {
    pageInfo {
      hasNextPage
      hasPreviousPage
    }
    edges {
      cursor
      node {
        id
        quantity
        merchandise {
          ...VariantWithProductFragment
        }
        attributes {
          key
          value
        }
        discountAllocations {
          discountedAmount {
            ...MoneyInfoFragment
          }
          ... on CartAutomaticDiscountAllocation {
            title
          }
          ... on CartCodeDiscountAllocation {
            code
          }
        }
        sellingPlanAllocation {
          sellingPlan {
            description
            id
            name
            options {
              name
              value
            }
            priceAdjustments {
              adjustmentValue {
                ... on SellingPlanFixedAmountPriceAdjustment {
                  adjustmentAmount {
                    ...MoneyInfoFragment
                  }
                }
                ... on SellingPlanFixedPriceAdjustment {
                  price {
                    ...MoneyInfoFragment
                  }
                }
                ... on SellingPlanPercentagePriceAdjustment {
                  adjustmentPercentage
                }
              }
              orderCount
            }
            recurringDeliveries
          }
        }
      }
    }
  }
`;
const cartFragment = `
  fragment CartFragment on Cart {
    id
    checkoutUrl
    createdAt
    updatedAt
    estimatedCost {
      subtotalAmount {
        ...MoneyInfoFragment
      }
      totalAmount {
        ...MoneyInfoFragment
      }
      totalDutyAmount {
        ...MoneyInfoFragment
      }
      totalTaxAmount {
        ...MoneyInfoFragment
      }
    }
    lines(first: ${constants_1.DEFAULT_PAGE_SIZE}) {
      ...CartLineConnectionFragment
    }
    discountCodes {
      applicable
      code
    }
  }
`;
exports.getProductByHandleQuery = gql_1.gql `
    query Product($handle: String!) {
        productByHandle(handle: $handle) {
            ...ProductFragment
        }
    }
    ${productFragment}
    ${productVariantFragment}
    ${imageConnectionFragment}
    ${productVariantPricePairConnectionFragment}
    ${exports.moneyInfoFragment}
`;
exports.getProductNodeQuery = gql_1.gql `
    query Product($id: ID!) {
        node(id: $id) {
            ...ProductFragment
        }
    }
    ${productFragment}
    ${productVariantFragment}
    ${imageConnectionFragment}
    ${productVariantPricePairConnectionFragment}
    ${exports.moneyInfoFragment}
`;
exports.getCreateCartMutation = gql_1.gql `
    mutation CreateCart($input: CartInput!) {
        cartCreate(input: $input) {
            userErrors {
                ...UserErrorFragment
            }
            cart {
                ...CartFragment
            }
        }
    }
    ${userErrorFragment}
    ${cartFragment}
    ${variantWithProductFragment}
    ${productVariantFragment}
    ${productVariantPricePairConnectionFragment}
    ${cartLineConnectionFragment}
    ${exports.moneyInfoFragment}
`;
exports.getCartLinesPageQuery = gql_1.gql `
    query CartLine($cartId: ID!, $pageSize: Int!, $cursor: String) {
        node(id: $cartId) {
            ... on Cart {
                lines(first: $pageSize, after: $cursor) {
                    ...CartLineConnectionFragment
                }
            }
        }
    }
    ${cartLineConnectionFragment}
    ${variantWithProductFragment}
    ${productVariantFragment}
    ${imageConnectionFragment}
    ${productVariantPricePairConnectionFragment}
    ${exports.moneyInfoFragment}
`;
exports.getCartQuery = gql_1.gql `
    query Cart($id: ID!) {
        cart(id: $id) {
            ...CartFragment
        }
    }
    ${cartFragment}
    ${variantWithProductFragment}
    ${productVariantFragment}
    ${productVariantPricePairConnectionFragment}
    ${cartLineConnectionFragment}
    ${exports.moneyInfoFragment}
`;
exports.getPresentmentPricesPageQuery = gql_1.gql `
    query PresentmentPrices($productVariantId: ID!, $pageSize: Int!, $cursor: String) {
        node(id: $productVariantId) {
            ... on ProductVariant {
                presentmentPrices(first: $pageSize, after: $cursor) {
                    ...ProductVariantPricePairConnectionFragment
                }
            }
        }
    }
    ${productVariantPricePairConnectionFragment}
    ${exports.moneyInfoFragment}
`;
exports.getProductImagesPageQuery = gql_1.gql `
    query ProductImages($productId: ID!, $pageSize: Int!, $cursor: String) {
        node(id: $productId) {
            ... on Product {
                images(first: $pageSize, after: $cursor) {
                    ...ImageConnectionFragment
                }
            }
        }
    }
    ${imageConnectionFragment}
`;
exports.getProductVariantQuery = gql_1.gql `
    query ProductVariant($id: ID!) {
        node(id: $id) {
            ... on ProductVariant {
                ...VariantWithProductFragment
            }
        }
    }
    ${productVariantFragment}
    ${variantWithProductFragment}
    ${productVariantPricePairConnectionFragment}
    ${exports.moneyInfoFragment}
`;
exports.getProductVariantsQuery = gql_1.gql `
    query ProductVariants($productId: ID!, $pageSize: Int!, $cursor: String) {
        node(id: $id) {
            ... on Product {
                variants(first: $pageSize, after: $cursor) {
                    ...ProductVariantFragment
                }
            }
        }
    }
    ${productVariantFragment}
    ${productVariantPricePairConnectionFragment}
`;
exports.getRemoveCartLinesMutation = gql_1.gql `
    mutation RemoveCartLines($cartId: ID!, $lineIds: [ID!]!) {
        cartLinesRemove(cartId: $cartId, lineIds: $lineIds) {
            userErrors {
                ...UserErrorFragment
            }
            cart {
                ...CartFragment
            }
        }
    }
    ${userErrorFragment}
    ${cartFragment}
    ${variantWithProductFragment}
    ${productVariantFragment}
    ${productVariantPricePairConnectionFragment}
    ${cartLineConnectionFragment}
    ${exports.moneyInfoFragment}
`;
exports.getUpdateCartLinesMutation = gql_1.gql `
    mutation UpdateCartLines($cartId: ID!, $lines: [CartLineUpdateInput!]!) {
        cartLinesUpdate(cartId: $cartId, lines: $lines) {
            userErrors {
                ...UserErrorFragment
            }
            cart {
                ...CartFragment
            }
        }
    }
    ${userErrorFragment}
    ${cartFragment}
    ${variantWithProductFragment}
    ${productVariantFragment}
    ${productVariantPricePairConnectionFragment}
    ${cartLineConnectionFragment}
    ${exports.moneyInfoFragment}
`;
exports.getAddCartLinesMutation = gql_1.gql `
    mutation AddCartLines($cartId: ID!, $lines: [CartLineInput!]!) {
        cartLinesAdd(lines: $lines, cartId: $cartId) {
            userErrors {
                ...UserErrorFragment
            }
            cart {
                ...CartFragment
            }
        }
    }
    ${userErrorFragment}
    ${cartFragment}
    ${variantWithProductFragment}
    ${productVariantFragment}
    ${productVariantPricePairConnectionFragment}
    ${cartLineConnectionFragment}
    ${exports.moneyInfoFragment}
`;
exports.getCurrenciesQuery = gql_1.gql `
    query getCurrencies {
        shop {
            paymentSettings {
                enabledPresentmentCurrencies
            }
        }
    }
`;
