import { MeasuredType, UnitOfMeasurement, Option, Image } from '../types';
export interface CartLineGraphQlType {
    id: string;
    title: string;
    merchandise: ProductVariantWithProductGraphQlType | null;
    quantity: number;
    attributes: CartAttributeGraphQlType[];
    discountAllocations: {
        discountedAmount: MoneyV2GraphQlType;
        title?: string | null;
        code?: string | null;
    }[];
    sellingPlanAllocation: CartLineSellingPlanAllocation | null;
}
export interface CartGraphQlType {
    id: string | number;
    checkoutUrl: string;
    createdAt: string | null;
    updatedAt: string | null;
    estimatedCost: CartEstimatedCostGraphQlType;
    lines: PagedConnection<CartLineGraphQlType>;
    attributes: CartAttributeGraphQlType[];
    discountCodes: CartDiscountCodeGraphQlType[];
}
export interface ProductGraphQlType {
    id: string;
    availableForSale: boolean;
    createdAt: string;
    updatedAt: string;
    descriptionHtml: string;
    description: string;
    handle: string;
    productType: string;
    title: string;
    vendor: string;
    publishedAt: string;
    onlineStoreUrl: string;
    options: Array<Option>;
    images: PagedConnection<Image>;
    variants: PagedConnection<ProductVariantGraphQlType>;
}
export interface CartAttributeGraphQlType {
    key: string;
    value: string;
}
export interface MoneyV2GraphQlType {
    amount: string;
    currencyCode: string;
}
export interface CartDiscountCodeGraphQlType {
    applicable: boolean;
    code: string;
}
export interface CartEstimatedCostGraphQlType {
    subtotalAmount: MoneyV2GraphQlType;
    totalAmount: MoneyV2GraphQlType;
    totalDutyAmount?: MoneyV2GraphQlType;
    totalTaxAmount?: MoneyV2GraphQlType;
}
export interface PresentmentPriceGraphQlType {
    price: MoneyV2GraphQlType;
    compareAtPrice: MoneyV2GraphQlType;
}
export interface ProductVariantGraphQlType {
    id: string;
    title: string;
    price: string;
    priceV2: MoneyV2GraphQlType;
    presentmentPrices: PagedConnection<PresentmentPriceGraphQlType>;
    weight: number;
    availableForSale: boolean;
    quantityAvailable: number;
    sku: string;
    compareAtPrice: string;
    compareAtPriceV2: MoneyV2GraphQlType;
    image: Image;
    selectedOptions: {
        name: string;
        value: string;
    }[];
    unitPrice: MoneyV2GraphQlType;
    unitPriceMeasurement: {
        measuredType: MeasuredType | null;
        quantityUnit: UnitOfMeasurement | null;
        quantityValue: number;
        referenceUnit: UnitOfMeasurement | null;
        referenceValue: number;
    };
}
export interface ProductVariantWithProductGraphQlType extends ProductVariantGraphQlType {
    product: {
        id: string;
        handle: string;
        title: string;
    };
}
export interface CurrenciesGraphQlType {
    shop: {
        paymentSettings: {
            enabledPresentmentCurrencies: string[];
        };
    };
}
export declare type CurrenciesWithPrices = Record<string, string>;
export interface PagedConnection<TEntity> {
    pageInfo: {
        hasNextPage: boolean;
        hasPreviousPage: boolean;
    };
    edges: {
        cursor: string;
        node: TEntity;
    }[];
}
export interface CartMutationResult {
    cart?: CartGraphQlType | null;
    userErrors?: unknown[];
}
export interface CartLineSellingPlan {
    description: string;
    id: string;
    name: string;
    options: {
        name: string;
        value: string;
    }[];
    priceAdjustments: {
        adjustmentValue: {
            adjustmentAmount?: MoneyV2GraphQlType;
            price?: MoneyV2GraphQlType;
            adjustmentPercentage?: MoneyV2GraphQlType;
        };
        orderCount: number;
    }[];
    recurringDeliveries: boolean;
}
export interface CartLineSellingPlanAllocation {
    sellingPlan: CartLineSellingPlan;
}
