"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createShopifyStorefrontCheckout = void 0;
const _1 = require(".");
const checkout_1 = require("../../../checkout");
const types_1 = require("../../../../types");
function createShopifyStorefrontCheckout(config) {
    if (!types_1.isShopifyStoreConfig(config))
        throw new Error('Invalid Store Configuration for Shopify.');
    const storeDomain = config.storeDomain !== undefined ? config.storeDomain : '';
    const platformDomain = config.storePlatformDomain !== undefined ? config.storePlatformDomain : '';
    let storefrontAccessToken = '';
    if (config.storeToken !== undefined)
        storefrontAccessToken = config.storeToken;
    else if (process.env.STORE_TOKEN !== undefined)
        storefrontAccessToken = process.env.STORE_TOKEN;
    const storeName = config.storeName !== undefined ? config.storeName : '';
    const storeId = config.storeId !== undefined ? config.storeId : '';
    const sharedCheckoutDomains = config.sharedCheckoutDomains;
    const shopifyStorefrontPlatform = new _1.ShopifyStorefrontPlatform({
        storeDomain,
        platformDomain,
        storefrontAccessToken,
    }, { storeName, storeId, sharedCheckoutDomains });
    return new checkout_1.Checkout({
        platform: shopifyStorefrontPlatform,
    });
}
exports.createShopifyStorefrontCheckout = createShopifyStorefrontCheckout;
