"use strict";
/* eslint-disable @typescript-eslint/strict-boolean-expressions */
/* eslint-disable no-restricted-syntax */
Object.defineProperty(exports, "__esModule", { value: true });
exports.cookieStorage = exports.storeSharedCartId = exports.syncCartIdWithSharedDomains = void 0;
/**
 * Syncs the `cartId` given with `sharedCheckoutDomains` via `window.postMessage`.
 *
 * @param sharedCheckoutDomains - List of domains to load in iframe.
 * @param cartId - Shopify checkout cart id.
 */
function syncCartIdWithSharedDomains(sharedCheckoutDomains, cartId) {
    for (const storeDomain of sharedCheckoutDomains) {
        const storeIframe = document.querySelector(`iframe[data-store-domain="${storeDomain}"]`);
        if (storeIframe && storeIframe.contentWindow) {
            storeIframe.contentWindow.postMessage({ message: 'save new cartId', cartId }, storeDomain);
        }
    }
    return cartId;
}
exports.syncCartIdWithSharedDomains = syncCartIdWithSharedDomains;
/**
 * Saves the `cartId` given in `storage` and return it.
 *
 * @param cartKey
 * @param cartId
 * @return `cartId` given.
 */
function storeSharedCartId(cartKey, cartId) {
    exports.cookieStorage.setItem(cartKey, cartId);
    localStorage.setItem(cartKey, cartId);
    return cartId;
}
exports.storeSharedCartId = storeSharedCartId;
exports.cookieStorage = {
    setItem(name, value) {
        document.cookie = name + '=' + value + ';' + ';Secure=true;SameSite=None';
    },
    getItem(name) {
        const cookieName = name + '=';
        const cookieCollection = document.cookie.split(';');
        for (let i = 0; i < cookieCollection.length; i++) {
            let cookie = cookieCollection[i];
            while (cookie.startsWith(' ')) {
                cookie = cookie.slice(1);
            }
            if (cookie.startsWith(cookieName)) {
                return cookie.slice(cookieName.length, cookie.length);
            }
        }
        return '';
    },
};
