"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateSelectCurrencyProps = exports.validateLineItems = exports.validateItems = exports.validateIds = exports.validateId = exports.validateArray = exports.validateObject = void 0;
function isObject(props) {
    return props && typeof props === 'object';
}
function isArray(array) {
    return Array.isArray(array);
}
function validateObject(props, title) {
    if (!isObject(props))
        throw new Error(`${title || 'props'} is not an object.`);
}
exports.validateObject = validateObject;
function validateArray(array, objectTitle) {
    if (!isArray(array))
        throw new Error(`${objectTitle || 'items'} is not an object.`);
}
exports.validateArray = validateArray;
function isValidId(id) {
    return typeof id === 'string';
}
function validateId(id) {
    if (!isValidId(id))
        throw new Error('id is not type of string.');
}
exports.validateId = validateId;
function validateIds(ids) {
    for (const itemId of ids) {
        if (!isValidId(itemId))
            throw new Error('All ids should be type of string.');
    }
}
exports.validateIds = validateIds;
function validateItems(items) {
    for (const item of items) {
        validateObject(item, 'item');
        if (!item.id)
            throw new Error('Please provide "id" property to every item.');
        if (!isValidId(item.id))
            throw new Error('All items should have property "id" of type string.');
        if (!item.quantity)
            throw new Error('Please provide "quantity" property for every item.');
    }
}
exports.validateItems = validateItems;
function validateLineItems(lineItems) {
    for (const lineItem of lineItems) {
        validateObject(lineItem, 'lineItem');
        if (!lineItem.variantId)
            throw new Error('Please provide "variantId" property to every lineItem.');
        if (!isValidId(lineItem.variantId))
            throw new Error('All lineItems should have property "variantId" of type string.');
        if (!lineItem.quantity)
            throw new Error('Please provide "quantity" property for every lineItem.');
    }
}
exports.validateLineItems = validateLineItems;
function validateSelectCurrencyProps(props) {
    validateObject(props, 'props');
    if (!props.currency)
        throw new Error('Please provide "currency" property');
    if (typeof props.currency !== 'string')
        throw new Error('Currency is not type of string');
    if (props.lineItems) {
        validateArray(props.lineItems);
        validateLineItems(props.lineItems);
    }
}
exports.validateSelectCurrencyProps = validateSelectCurrencyProps;
