"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Inventory = void 0;
const tslib_1 = require("tslib");
const utils_1 = require("./utils");
class Inventory {
    constructor({ platform }) {
        this.platform = platform;
        this.productInventoryUrl = utils_1.getProductInventoryUrl();
    }
    fetchInventory() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            try {
                const response = yield fetch(this.productInventoryUrl);
                return response.json();
            }
            catch (_a) {
                return Promise.resolve({
                    products: {},
                    productVariants: {},
                });
            }
        });
    }
    refreshInventoryOnInterval(callback) {
        const interval = Number(process.env.NEXT_PRODUCT_INVENTORY_REFRESH_INTERVAL || process.env.PRODUCT_INVENTORY_REFRESH_INTERVAL);
        if (isNaN(interval))
            return undefined;
        const defaultInterval = 1000 * 60; // 1 minute
        return window.setInterval(() => tslib_1.__awaiter(this, void 0, void 0, function* () {
            try {
                const inventory = yield this.fetchInventory();
                callback(inventory);
            }
            catch (_a) { }
        }), Number(interval) || defaultInterval);
    }
    fetchProductsInventory(itemIds, productType) {
        return this.platform.fetchProductsInventory(itemIds, productType);
    }
    refreshPlatformInventory({ ids, interval, productType, callback, errorCallback, }) {
        const intervalNumber = Number(interval);
        if (!intervalNumber || intervalNumber < 0)
            return;
        // 24.855 days max available value for timeout / interval in browsers,
        // for the higher value it will be called immediately
        const maxAvailableInterval = Math.pow(2, 31) - 1;
        const intervalValue = intervalNumber < maxAvailableInterval ? intervalNumber : maxAvailableInterval;
        return window.setInterval(() => tslib_1.__awaiter(this, void 0, void 0, function* () {
            try {
                const platformInventory = yield this.fetchProductsInventory(ids, productType);
                callback(platformInventory);
            }
            catch (_a) {
                errorCallback();
            }
        }), intervalValue);
    }
    isProductAvailableForSale(itemId, productType) {
        return this.platform.isProductAvailableForSale(itemId, productType);
    }
    getProductQuantity(itemId, productType) {
        return this.platform.getProductQuantity(itemId, productType);
    }
    getProductMinOrder(itemId, productType) {
        return this.platform.getProductMinOrder(itemId, productType);
    }
    getProductMaxOrder(itemId, productType) {
        return this.platform.getProductMaxOrder(itemId, productType);
    }
    getProductPrice(itemId, productType) {
        return this.platform.getProductPrice(itemId, productType);
    }
}
exports.Inventory = Inventory;
