"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getCatalogForProductsPath = exports.api = void 0;
const tslib_1 = require("tslib");
const queries_1 = require("./queries");
const getDataFromResponse = (response) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    if (!response.ok)
        throw new Error(`${response.statusText} ${response.status}`);
    return yield response.json();
});
// TODO: This should be refactored so it can be re-used across the package
const fetcher = (method) => (url, body) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    const response = yield fetch(url, {
        method,
        headers: {
            Accept: 'application/json',
            'Content-Type': 'application/json',
        },
        body: typeof body === 'string' ? body : JSON.stringify(body),
    });
    return getDataFromResponse(response);
});
const inventoryIncludeFields = [
    'id',
    'price',
    'inventory_level',
    'inventory_tracking',
    'availability',
    'order_quantity_minimum',
    'order_quantity_maximum',
];
const includeFieldsQuery = inventoryIncludeFields.join(',');
const getCatalogForProductsPath = (productIds) => `/v3/catalog/products?id:in=${productIds}&include_fields=${includeFieldsQuery}`;
exports.getCatalogForProductsPath = getCatalogForProductsPath;
const getCatalogWithProductVariantsPath = (productIds) => `/v3/catalog/products?id:in=${productIds}&include_fields=${includeFieldsQuery}&include=variants`;
const api = {
    fetchInventoryByProductIds: (productIds) => fetcher('GET')(getCatalogForProductsPath(productIds.join(','))),
    fetchInventoryWithVariantsByProductIds: (productIds) => fetcher('GET')(getCatalogWithProductVariantsPath(productIds.join(','))),
    fetchProductIdByVariantId: (variantId) => fetcher('POST')('/graphql', queries_1.getProductIdByVariantIdQuery({ variantId })),
};
exports.api = api;
