"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Client = void 0;
const tslib_1 = require("tslib");
/* eslint-disable no-restricted-syntax */
/* eslint-disable unicorn/no-nested-ternary */
/* eslint-disable @typescript-eslint/strict-boolean-expressions */
const queries_1 = require("./queries");
const types_1 = require("../../types");
const getDataFromResponse = (response) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    if (!response.ok)
        throw new Error(`${response.statusText} ${response.status}`);
    try {
        return yield response.json();
    }
    catch (_a) {
        return response;
    }
});
const fetcher = (method) => (url, headers, body) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    const response = yield fetch(url, {
        method,
        headers,
        body,
    });
    return getDataFromResponse(response);
});
//Get this from constants
const STOREFRONT_API_VERSION = '2021-10';
class Client {
    constructor(config) {
        if (!types_1.isShopifyStoreConfig(config))
            throw new Error('Invalid Store Configuration for Shopify.');
        const { storeToken, storePlatformDomain, storeDomain } = config;
        this.platformDomain = storePlatformDomain;
        this.storeDomain = storeDomain;
        this.defaultHeaders = {
            'X-Shopify-Storefront-Access-Token': storeToken || '',
            'Accept-Language': '*',
            'Content-Type': 'application/json',
            Accept: 'application/json',
        };
        const baseApiUrl = this.platformDomain
            ? `https://${this.platformDomain}`
            : this.storeDomain
                ? `https://${this.storeDomain}`
                : '';
        this.apiUrl = `${baseApiUrl}/api/${STOREFRONT_API_VERSION}/graphql`;
    }
    fetchInventoryByProductIds(ids) {
        return fetcher('POST')(this.apiUrl, this.defaultHeaders, queries_1.getProductsInventoryDataQuery({ ids }));
    }
}
exports.Client = Client;
