import { ItemId, ProductType, SupportedPlatform, StoreConfig, isShopifyStoreConfig } from '../types';
import { BigCommerceInventory } from './platforms/big-commerce/types';
import { ShopifyInventory } from './platforms/shopify/types';
import { ProductInventory } from './platforms/types';
declare type InventoryHelperConfig = StoreConfig & {
    defaultProductType: ProductType;
};
interface Product {
    availableForSale: boolean;
    quantity: number;
    minOrder?: number;
    maxOrder?: number;
}
declare type Variant = Product;
declare type Products = Record<ItemId, Product>;
declare type Variants = Record<ItemId, Variant>;
declare type InventoryJSONResponse = {
    products: Products;
    productVariants: Variants;
};
interface InventoryJSONData {
    products: Products | undefined | null;
    productVariants: Variants | undefined | null;
    status: 'loading' | 'loaded' | 'error';
}
interface BaseInventoryHelper {
    refreshInventoryOnInterval(callback: (inventoryData: InventoryJSONResponse) => void): number | undefined;
    refreshPlatformInventory(props: {
        ids: ItemId[];
        interval: number;
        productType?: ProductType;
        callback: (platformInventory: BigCommerceInventory | ShopifyInventory) => void;
    }): number | undefined;
}
interface PlatformInventoryHelper {
    fetchProductsInventory(itemIds: ItemId[], productType?: ProductType): Promise<BigCommerceInventory | ShopifyInventory>;
    isProductAvailableForSale(itemId: ItemId, productType?: ProductType): Promise<ProductInventory['availableForSale']>;
    getProductQuantity(itemId: ItemId, productType?: ProductType): Promise<ProductInventory['quantity']>;
    getProductMinOrder(itemId: ItemId, productType?: ProductType): Promise<ProductInventory['minOrder']>;
    getProductMaxOrder(itemId: ItemId, productType?: ProductType): Promise<ProductInventory['maxOrder']>;
    getProductPrice(itemId: ItemId, productType?: ProductType): Promise<ProductInventory['price']>;
}
declare type InventoryHelper = BaseInventoryHelper & PlatformInventoryHelper;
export { InventoryHelper, PlatformInventoryHelper, InventoryHelperConfig, InventoryJSONResponse, InventoryJSONData, ItemId, SupportedPlatform, isShopifyStoreConfig, };
