"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useInventory = void 0;
const tslib_1 = require("tslib");
/* eslint-disable react-hooks/exhaustive-deps */
/* eslint-disable @typescript-eslint/strict-boolean-expressions */
const react_1 = require("react");
const context_1 = require("../checkout-hooks/context");
const useInventory = (props) => {
    const { ids, productType, interval } = props || {};
    const inventoryActions = context_1.useInventoryActions();
    const [inventory, setInventory] = react_1.useState({
        products: {},
        status: (ids === null || ids === void 0 ? void 0 : ids.length) ? 'loading' : 'initial',
    });
    const idsRef = react_1.useRef(ids);
    const statusRef = react_1.useRef(inventory.status);
    statusRef.current = inventory.status;
    const itemIds = react_1.useMemo(() => {
        var _a, _b, _c;
        const isEqual = ids &&
            idsRef.current &&
            ((_a = idsRef.current) === null || _a === void 0 ? void 0 : _a.length) === (ids === null || ids === void 0 ? void 0 : ids.length) &&
            ((_c = (_b = idsRef.current).every) === null || _c === void 0 ? void 0 : _c.call(_b, (id) => { var _a; return (_a = ids.includes) === null || _a === void 0 ? void 0 : _a.call(ids, id); }));
        if (isEqual) {
            return idsRef.current;
        }
        idsRef.current = ids;
        return ids;
    }, [ids]);
    const handleInventoryChange = react_1.useCallback((platformInventory) => {
        setInventory({ products: platformInventory, status: 'loaded' });
    }, [setInventory]);
    const setInventoryStatus = react_1.useCallback((status) => {
        setInventory((inventory) => (Object.assign(Object.assign({}, inventory), { status })));
    }, [setInventory]);
    react_1.useEffect(() => {
        if (!(itemIds === null || itemIds === void 0 ? void 0 : itemIds.length))
            return;
        if (statusRef.current !== 'loading') {
            setInventoryStatus('loading');
        }
        const fetchProductInventory = () => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
            try {
                const platformInventory = yield inventoryActions.fetchProductsInventory(ids, productType);
                handleInventoryChange(platformInventory);
            }
            catch (_a) {
                setInventoryStatus('error');
            }
        });
        fetchProductInventory();
        if (interval === undefined)
            return;
        const intervalId = inventoryActions.refreshPlatformInventory({
            ids: itemIds,
            interval,
            productType,
            callback: handleInventoryChange,
            errorCallback: () => setInventoryStatus('error'),
        });
        return () => {
            clearInterval(intervalId);
        };
        // We only want to react to itemIds and productType changes
    }, [itemIds, productType]);
    return inventory;
};
exports.useInventory = useInventory;
