"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.fetchPool = void 0;
class PromiseListener {
    constructor() {
        this.listeners = [];
        this.addListener = (action) => {
            this.listeners = this.listeners.concat(action);
        };
        this.removeListener = (action) => {
            this.listeners = this.listeners.filter((listenerAction) => listenerAction !== action);
        };
        this.dispatch = () => {
            if (this.listeners.length > 0) {
                const [action] = this.listeners;
                action();
                this.removeListener(action);
            }
        };
    }
}
const shuffle = (array) => {
    const newArray = [...array];
    for (let i = newArray.length - 1; i > 0; i--) {
        const j = Math.floor(Math.random() * (i + 1));
        [newArray[i], newArray[j]] = [newArray[j], newArray[i]];
    }
    return newArray;
};
// Fetch promises in concurrency
const fetchPool = (props) => {
    const { actions, concurrency, random = true } = props;
    const promiseListener = new PromiseListener();
    const poolActions = random ? shuffle(actions) : actions;
    const promiseAction = (action) => new Promise((resolve) => {
        promiseListener.addListener(() => resolve(action()));
    });
    const pool = poolActions.map((action, index) => {
        const promise = () => {
            if (concurrency > index) {
                return action();
            }
            return promiseAction(action);
        };
        return promise().then((data) => {
            promiseListener.dispatch();
            return data;
        });
    });
    return Promise.all(pool);
};
exports.fetchPool = fetchPool;
